# Latest Earthquake in Indonesia
Latest Earthquake Indonesia from Indonesian Agency for Meteorology, Climatology, and Geophysics (BMKG)

## ABOUT
This Package will scrape from [BMKG](https://www.bmkg.go.id/) to get latest earthquake in Indonesia.

Using Library BeautifulSoup4 and Request, to produce output in the form of JSON that is ready to be used in web or mobile apps.
